{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<div class="d-flex align-items-center pt-xl-5 px-5 ms-xl-4 pt-5 pt-xl-0 mt-xl-5">
    <form style="width: 23rem;" method="post">
        {% csrf_token %}
        <h3 class="fw-normal mb-3 pb-3" style="letter-spacing: 1px;">{{_('reset_password')}}</h3>

        <div class="form-outline mb-4">
            <input type="password" id="id_new_password1" name="new_password1"
                   class="form-control form-control-lg"
                   autocomplete="new_password1"/>
            <label class="form-label" for="id_new_password1">{{ form.new_password1.label }}</label>
        </div>
        <div class="text-danger">
            {% if form.new_password1.errors %} {{form.new_password1.errors}} {% endif %}
        </div>
        {% if form.new_password1.errors %} {{form.new_password1.help_text}} {% endif %}
        <div class="form-outline mb-4">
            <input type="password" id="id_new_password2" name="new_password2"
                   class="form-control form-control-lg"
                   autocomplete="new_password2"/>
            <label class="form-label" for="id_new_password2">{{ form.new_password2.label }}</label>
        </div>
        <div class="text-danger">
            {% if form.new_password2.errors %} {{form.new_password2.errors}} {% endif %}
        </div>
        {% if form.new_password2.errors %} {{form.new_password2.help_text}} {% endif %}

        <div class="pt-1 mb-4">
            <button class="btn btn-info btn-lg btn-block" type="submit">{{_('reset_password')}}</button>
        </div>
    </form>
</div>
{% endblock %}